@@ -57,9 +57,11 @@ for my $constant ( $xml->getElementsByTagName('PhysicalConstant') ) {
 
 
 	push @long, $long_name if $long_name;
-	push @short, $short_name if $short_name;
+	push @short, '$' . $short_name if $short_name;
 		
-	if ( my $alternate = $constant->getChildrenByTagName('alternateName')->shift()->textContent() ) {
+	my $alternate;
+	if ( $constant->getChildrenByTagName('alternateName')
+			&& ($alternate = $constant->getChildrenByTagName('alternateName')->shift()->textContent()) ) {
 		push @long, $alternate;
 		write_constant($mks_fh, ($values->{mks} || $values->{value}), $alternate) if $values->{mks} || $values->{value};
 		write_constant($cgs_fh, ($values->{cgs} || $values->{value}), $alternate) if $values->{cgs} || $values->{value};
@@ -90,6 +92,7 @@ HEADER
 use strict;
 use warnings;
 use base qw/Exporter/;
+use Scalar::Constant;
 
 IMPORT
 	}
@@ -166,12 +169,31 @@ and are mostly based on the 2014 CODATA values from NIST.
 
 The problem with long constants is that they are not interpolated
 in double quotish situations because they are really inlined functions.
-The problem with short name constants is that they are not read-only
-and can be assigned to which will mess up your program.
+The problem with short name constants is that they use L<Scalar::Constant>
+instead of L<constant> and are 33% slower.
+
+=head2 Why use this module
+
+You are tired of typing in all those numbers and having to make sure that they are
+all correct.  How many significant figures is enough or too much?  Where's the
+definitive source, Wikipedia?  And which mass does "$m1" refer to, solar or lunar?
+
+The constant values in this module are protected against accidental re-assignment
+in your code.  The test suite protects them against accidental finger trouble in my code. 
+Other people are using this module, so more eyeballs are looking for errors
+and we all benefit.  The constant names are a little longer than you might like,
+but you gain in the long run from readable, sharable code that is clear in meaning.
+Your programming errors are a little easier to find when you can see that the units 
+don't match.  Isn't it reassuring that you can verify how a number is produced
+and which meeting of which standards body is responsible for its value?
+
+Trusting someone else's code does carry some risk, which you _should_ consider, 
+but have you also considered the risk of doing it yourself with no one to check your work?
 
 =head1 EXPORT
 
-Nothing is exported by default.  Select from the following tags:
+Nothing is exported by default, so the module doesn't clobber any of your variables.  
+Select from the following tags:
 
 =for :list
 * long		(use this one to get the most constants)
@@ -197,14 +219,24 @@ sub write_pod_footer {
 * L<Astro::Cosmology>
 * L<PDL|Perl Data Language>
 * L<http://physics.nist.gov/|NIST>
+* L<http://asa.usno.navy.mil|Astronomical Almanac>
 * L<http://neilb.org/reviews/constants.html|Neil Bower's review on providing read-only values>
+* L<Test::Number::Delta>
+* L<Test::Deep::NumberTolerant> for testing values within objects
+
+Reference Documents:
+=for :list
+* L<http://aa.usno.navy.mil/publications/reports/Luzumetal2011.pdf|IAU 2009 system of astronomical constants>
+* L<http://asa.usno.navy.mil/static/files/2016/Astronomical_Constants_2016.pdf|Astronomical Constants 2016.pdf>
+* L<https://www.iau.org/publications/proceedings_rules/units/|IAU recommendations concerning units>
+* L<http://syrte.obspm.fr/IAU_resolutions/Res_IAU2012_B2.pdf|Re-definition of the Astronomical Unit>
 
 =head1 ISSUES
 
 File issues at the Github repository L<https://github.com/duffee/Astro-Constants/>
 
 Using C<strict> is a must with this code.  Any constants you forgot to import will
-evaluate to 0 and silently introduce errors in your code.
+evaluate to 0 and silently introduce errors in your code.  Caveat Programmer.
 
 =head2 Extending the data set
 
@@ -248,7 +280,7 @@ No warranty expressed or implied.  This is free software.  If you
 want someone to assume the risk of an incorrect value, you better
 be paying them.
 
-(What would you want me to test for you to depend on this module?)
+(What would you want me to test in order for you to depend on this module?)
 
 I<from Jeremy Bailin's astroconst header files>
 
@@ -277,5 +309,5 @@ sub write_constant {
 	my ($fh, $value, $long_name, $short_name) = @_;
 
 	say $fh "use constant $long_name => $value;";
-	say $fh "use constant $short_name => $value;" if $short_name;
+	say $fh "use Scalar::Constant $short_name => $value;" if $short_name;
 }
